==> haskell-tasty-ant-xml-1.1.9-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-ant-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-ant-xml
version:              1.1.9
visibility:           public
id:                   tasty-ant-xml-1.1.9-AITmoMqLLkEAp5LaQfmNBM
key:                  tasty-ant-xml-1.1.9-AITmoMqLLkEAp5LaQfmNBM
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  16d4740ab058a22a0fa5a30d64480572
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-ant-xml
hs-libraries:         HStasty-ant-xml-1.1.9-AITmoMqLLkEAp5LaQfmNBM
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    generic-deriving-1.14.6-8oUUQNjeWD5GBbISYaOAv9 ghc-prim-0.9.1
    mtl-2.2.2 stm-2.5.1.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-GY0eM8VtajpCuQaxkRLQvT transformers-0.5.6.2
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-ant-xml-1.1.9-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-ant-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-ant-xml
version:              1.1.9
visibility:           public
id:                   tasty-ant-xml-1.1.9-InMakQwFMsSA8147eeEctG
key:                  tasty-ant-xml-1.1.9-InMakQwFMsSA8147eeEctG
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  359f3b13f61fbb50af4980ea918d9fd3
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-ant-xml
hs-libraries:         HStasty-ant-xml-1.1.9-InMakQwFMsSA8147eeEctG
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    generic-deriving-1.14.6-4z3hiP8paBtI4NvEB71fp5 ghc-prim-0.9.1
    mtl-2.2.2 stm-2.5.1.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-FZEVHmEaz6e1recPNofOF8 transformers-0.5.6.2
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
